{ config, pkgs, ... }:

{
  imports =
    [
      ../../base.nix
      ../../common/metrics-exporters.nix
      ./hardware-configuration.nix
      ./containers.nix

      ./services/metrics

      # TODO:
      # - Boots
      # - Transmission
      # - Jellyfin
      # - NFS exports
      # x Monitoring server
      # - Kali VM
      # - Kerberos / IPA
    ];

  boot = {
    kernelPackages = config.boot.zfs.package.latestCompatibleLinuxPackages;
    kernelParams = [ "nohibernate" ]; # No swap, no hibernate
    supportedFilesystems = [ "zfs" ];
  };

  # filesystems."/tank" = {
  #   device = "tank";
  #   fsType = "zfs";
  # };

  networking = {
    hostName = "voyager";
    defaultGateway = "192.168.10.1";
    nameservers = [ "192.168.10.1" "1.1.1.1" ];
    interfaces.eth0.ipv4 = {
      addresses = [
        { address = "192.168.10.165"; prefixLength = 24; }
      ];
    };
    hostId = "8e84b235";
  };

  environment.variables = { EDITOR = "vim"; };
  environment.systemPackages = with pkgs; [
    ((vim_configurable.override {  }).customize{
       name = "vim";
       vimrcConfig.packages.myplugins = with pkgs.vimPlugins; {
       start = [ vim-nix vim-lastplace ];
       opt = [];
     };
     vimrcConfig.customRC = ''
     " your custom vimrc
     set number
     set relativenumber
     set nu rnu
     set signcolumn=number

     set hlsearch
     set smartcase
     set incsearch

     set autoindent
     set expandtab
     set shiftwidth=2
     set tabstop=2
     set smartindent
     set smarttab

     set ruler

     set undolevels=1000

     set nocompatible
     set backspace=indent,eol,start
     " Turn on syntax highlighting by default
     syntax on
     " ...
     '';
    }
  )
    wget
    git
    tree
    rsync
    bottom
  ];

  networking.firewall.allowedTCPPorts = [ 22 ];

  system.stateVersion = "22.11";

}

